summaryrefslogtreecommitdiff
path: root/gcc/real.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/real.c')
-rw-r--r--gcc/real.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gcc/real.c b/gcc/real.c
index ad0b160f3d5..0d8547b9c7d 100644
--- a/gcc/real.c
+++ b/gcc/real.c
@@ -507,7 +507,7 @@ normalize (r)
int shift = 0, exp;
int i, j;
/* Find the first word that is non-zero. */
for (i = SIGSZ - 1; i >= 0; i--)
if (r->sig[i] == 0)
shift += HOST_BITS_PER_LONG;
@@ -522,7 +522,7 @@ normalize (r)
return;
}
/* Find the first bit that is non-zero. */
for (j = 0; ; j++)
if (r->sig[i] & ((unsigned long)1 << (HOST_BITS_PER_LONG - 1 - j)))
break;
@@ -2114,7 +2114,7 @@ round_for_format (fmt, r)
}
/* There are P2 true significand bits, followed by one guard bit,
- followed by one sticky bit, followed by stuff. Fold non-zero
+ followed by one sticky bit, followed by stuff. Fold nonzero
stuff into the sticky bit. */
sticky = 0;
@@ -507,7 +507,7 @@ normalize (r)
int shift = 0, exp;
int i, j;
- /* Find the first word that is non-zero. */
+ /* Find the first word that is nonzero. */
for (i = SIGSZ - 1; i >= 0; i--)
if (r->sig[i] == 0)
@@ -522,7 +522,7 @@ normalize (r)
return;
}
- /* Find the first bit that is non-zero. */
+ /* Find the first bit that is nonzero. */
for (j = 0; ; j++)
if (r->sig[i] & ((unsigned long)1 << (HOST_BITS_PER_LONG - 1 - j)))